import type { IndexDefinition as _IndexDefinition } from 'mongodb-data-service';
import type { AnyAction } from 'redux';
import type { ThunkAction } from 'redux-thunk';
import type { CreateIndexSpec } from './create-index';
import type { RootState } from '.';
export type SortColumn = keyof typeof sortColumnToProps;
export type SortDirection = 'asc' | 'desc';
declare const sortColumnToProps: {
    readonly 'Name and Definition': "name";
    readonly Type: "type";
    readonly Size: "size";
    readonly Usage: "usageCount";
    readonly Properties: "properties";
};
export type IndexDefinition = Omit<_IndexDefinition, 'type' | 'cardinality' | 'properties' | 'version'> & Partial<_IndexDefinition>;
export type InProgressIndex = {
    id: string;
    key: CreateIndexSpec;
    fields: {
        field: string;
        value: string | number;
    }[];
    name: string;
    ns: string;
    size: number;
    relativeSize: number;
    usageCount: number;
    extra: {
        status: 'inprogress' | 'failed';
        error?: string;
    };
};
export declare enum ActionTypes {
    IndexesAdded = "indexes/regular-indexes/IndexesAdded",
    IndexesSorted = "indexes/regular-indexes/IndexesSorted",
    SetIsRefreshing = "indexes/regular-indexes/SetIsRefreshing",
    SetError = "indexes/regular-indexes/SetError",
    InProgressIndexAdded = "indexes/regular-indexes/InProgressIndexAdded",
    InProgressIndexRemoved = "indexes/regular-indexes/InProgressIndexRemoved",
    InProgressIndexFailed = "indexes/regular-indexes/InProgressIndexFailed"
}
type IndexesAddedAction = {
    type: ActionTypes.IndexesAdded;
    indexes: IndexDefinition[];
};
type IndexesSortedAction = {
    type: ActionTypes.IndexesSorted;
    indexes: IndexDefinition[];
    sortOrder: SortDirection;
    sortColumn: SortColumn;
};
type SetIsRefreshingAction = {
    type: ActionTypes.SetIsRefreshing;
    isRefreshing: boolean;
};
type SetErrorAction = {
    type: ActionTypes.SetError;
    error: string | null;
};
type InProgressIndexAddedAction = {
    type: ActionTypes.InProgressIndexAdded;
    index: InProgressIndex;
};
type InProgressIndexRemovedAction = {
    type: ActionTypes.InProgressIndexRemoved;
    id: string;
};
type InProgressIndexFailedAction = {
    type: ActionTypes.InProgressIndexFailed;
    id: string;
    error: string;
};
export type State = {
    indexes: IndexDefinition[];
    sortOrder: SortDirection;
    sortColumn: SortColumn;
    isRefreshing: boolean;
    inProgressIndexes: InProgressIndex[];
    error: string | null;
};
export declare const INITIAL_STATE: State;
export default function reducer(state: State | undefined, action: AnyAction): State;
export declare const setIndexes: (indexes: IndexDefinition[]) => IndexesAddedAction;
export declare const setError: (error: string | null) => SetErrorAction;
export declare const fetchIndexes: () => ThunkAction<Promise<void>, RootState, void, IndexesAddedAction | SetIsRefreshingAction | SetErrorAction>;
export declare const sortIndexes: (column: SortColumn, order: SortDirection) => ThunkAction<void, RootState, void, IndexesSortedAction>;
export declare const refreshIndexes: () => ThunkAction<void, RootState, void, AnyAction>;
export declare const inProgressIndexAdded: (inProgressIndex: InProgressIndex) => InProgressIndexAddedAction;
export declare const inProgressIndexRemoved: (inProgressIndexId: string) => InProgressIndexRemovedAction;
export declare const inProgressIndexFailed: ({ inProgressIndexId, error, }: {
    inProgressIndexId: string;
    error: string;
}) => InProgressIndexFailedAction;
export declare const dropFailedIndex: (id: string) => ThunkAction<void, RootState, void, AnyAction>;
export declare const hideIndex: (indexName: string) => ThunkAction<Promise<void>, RootState, void, AnyAction>;
export declare const unhideIndex: (indexName: string) => ThunkAction<Promise<void>, RootState, void, AnyAction>;
export {};
//# sourceMappingURL=regular-indexes.d.ts.map